load_config

Function load_config 

pub fn load_config(explicit_path: Option<&Path>) -> Result<TalonConfig>
Loads config from the default path or an explicit path.

Errors

Returns an error if the config file cannot be found or parsed.