pub fn sync_lock_path(config: &TalonConfig) -> PathBufExpand description
Returns the advisory sync lock path for a configured database.
pub fn sync_lock_path(config: &TalonConfig) -> PathBufReturns the advisory sync lock path for a configured database.