Module platform

Module platform 

Platform initialization and terminal detection.

Functions

start
Initializes platform-specific terminal behavior.
stderr_is_tty
Returns whether stderr is connected to an interactive terminal.
stdout_is_tty
Returns whether stdout is connected to an interactive terminal.
user_accepts_ansi_color
Returns whether the user permits ANSI color.